@@ -22,19 +22,18 @@ class UserFixture(AutoFixture):
     * ``date_joined`` and ``last_login`` are always in the past and it is
       assured that ``date_joined`` will be lower than ``last_login``.
     '''
-    field_values = {
-        'username': generators.StringGenerator(chars=
-            string.ascii_letters + string.digits + '_'),
-        'first_name': generators.LoremWordGenerator(1),
-        'last_name': generators.LoremWordGenerator(1),
-        'password': UNUSABLE_PASSWORD,
-        'is_active': True,
+    class Values(object):
+        username = generators.StringGenerator(chars=
+            string.ascii_letters + string.digits + '_')
+        first_name = generators.LoremWordGenerator(1)
+        last_name = generators.LoremWordGenerator(1)
+        password = UNUSABLE_PASSWORD
+        is_active = True
         # don't generate admin users
-        'is_staff': False,
-        'is_superuser': False,
-        'date_joined': generators.DateTimeGenerator(max_date=datetime.now()),
-        'last_login': generators.DateTimeGenerator(max_date=datetime.now()),
-    }
+        is_staff = False
+        is_superuser = False
+        date_joined = generators.DateTimeGenerator(max_date=datetime.now())
+        last_login = generators.DateTimeGenerator(max_date=datetime.now())
 
     # don't follow permissions and groups
     follow_m2m = False
