@@ -237,14 +237,16 @@ class NullBooleanGenerator(BooleanGenerator):
 
 
 class DateTimeGenerator(Generator):
-    min_date = datetime.datetime.now() - datetime.timedelta(365 * 5)
-    max_date = datetime.datetime.now() + datetime.timedelta(365 * 1)
-
     def __init__(self, min_date=None, max_date=None, *args, **kwargs):
+        from django.utils import timezone
         if min_date is not None:
             self.min_date = min_date
+        else:
+            self.min_date = timezone.now() - datetime.timedelta(365 * 5)
         if max_date is not None:
             self.max_date = max_date
+        else:
+            self.max_date = timezone.now() + datetime.timedelta(365 * 1)
         assert self.min_date < self.max_date
         super(DateTimeGenerator, self).__init__(*args, **kwargs)
 
@@ -298,26 +300,35 @@ class DecimalGenerator(Generator):
 class EmailGenerator(StringGenerator):
     chars = string.ascii_lowercase
 
-    def __init__(self, chars=None, max_length=30, tlds=None, *args, **kwargs):
+    def __init__(self, chars=None, max_length=30, tlds=None, static_domain=None, *args, **kwargs):
         assert max_length >= 6
         if chars is not None:
             self.chars = chars
         self.tlds = tlds
+        self.static_domain = static_domain
         super(EmailGenerator, self).__init__(self.chars, max_length=max_length, *args, **kwargs)
 
     def generate(self):
         maxl = self.max_length - 2
-        if self.tlds:
-            tld = random.choice(self.tlds)
-        elif maxl > 4:
-            tld = StringGenerator(self.chars, min_length=3, max_length=3).generate()
-        maxl -= len(tld)
-        assert maxl >= 2
+
+        if self.static_domain is None:
+            if self.tlds:
+                tld = random.choice(self.tlds)
+            elif maxl > 4:
+                tld = StringGenerator(self.chars, min_length=3, max_length=3).generate()
+            maxl -= len(tld)
+            assert maxl >= 2
+        else:
+            maxl -= len(self.static_domain)
 
         name = StringGenerator(self.chars, min_length=1, max_length=maxl-1).generate()
         maxl -= len(name)
-        domain = StringGenerator(self.chars, min_length=1, max_length=maxl).generate()
-        return '%s@%s.%s' % (name, domain, tld)
+
+        if self.static_domain is None:
+            domain = StringGenerator(self.chars, min_length=1, max_length=maxl).generate()
+            return '%s@%s.%s' % (name, domain, tld)
+        else:
+            return '%s@%s' % (name, self.static_domain)
 
 
 class URLGenerator(StringGenerator):
